@@ -26,12 +26,10 @@ create_theme  <- function(name = "theme", edit = TRUE) {
   bullet <- "v"
   circle <- "o"
 
-  cat(paste(bullet, "Created CSS file at theme.css"), "\n", sep = "")
-  cat(paste(circle, "TODO: Customize it to suit your needs"), "\n", sep = "")
+  cat(paste(bullet, "Created CSS file at", css), "\n")
+  cat(paste(circle, "TODO: Customize it to suit your needs"), "\n")
   cat(
-    paste(circle, "TODO: Add 'theme' entry to your`site/article YAML\n"),
-    "\n", sep = ""
-    )
-  cat("See docs at https://rstudio.github.io/distill/website.html#theming",
-      sep = "")
+    paste0(circle, " ", "TODO: Add 'theme: ", css, "' to your site or article YAML", "\n"),
+    "\n")
+  cat("See docs at https://rstudio.github.io/distill/website.html#theming")
 }
